def str_to_bool(s):
    if s == "True" or s == "true" or s == "1":
        return True
    elif s == "False" or s == "false" or s == "0":
        return False
    else:
        raise ValueError("Cannot convert {} to a bool".format(s))


from setuptools import setup, find_packages

setup(
    name='ezyli_utils',
    version='2.0.4',
    packages=find_packages(),
    install_requires=[
        'pika==1.3.2',
        'jsonschema==4.20.0'
    ],
)